## ----include = FALSE----------------------------------------------------------
library(knitr)
knitr::opts_chunk$set(
    collapse = TRUE,
    eval = FALSE,
    comment = "#>",
    cache = TRUE
)

## ----install, eval=FALSE------------------------------------------------------
#  BiocManager::install(MGnifyR)

## ----load_package-------------------------------------------------------------
#  library(MGnifyR)

## ----create_client, message = FALSE-------------------------------------------
#  mg <- MgnifyClient()
#  mg

## ----search_studies-----------------------------------------------------------
#  # Fetch studies
#  samples <- doQuery(
#      mg,
#      type = "samples",
#      biome_name = "root:Environmental:Aquatic:Freshwater:Drinking water",
#      max.hits = 10)
#  
#  # For demonstrative purpose, take only few samples
#  set.seed(595)
#  samples <- samples[ sample(rownames(samples), 5), ]

## ----convert_to_analyses------------------------------------------------------
#  analyses_accessions <- searchAnalysis(mg, "samples", samples$accession)
#  
#  head(analyses_accessions)

## ----get_metadata-------------------------------------------------------------
#  analyses_metadata <- getMetadata(mg, analyses_accessions)
#  
#  head(analyses_metadata)

## ----get_mae------------------------------------------------------------------
#  mae <- getResult(mg, accession = analyses_accessions)
#  mae

## ----mae_access---------------------------------------------------------------
#  mae[[1]]

## ----calculate_diversity------------------------------------------------------
#  mae[[1]] <- estimateDiversity(mae[[1]], index = "shannon")
#  
#  library(scater)
#  
#  plotColData(mae[[1]], "shannon", x = "sample_environment.feature")

## ----plot_abundance-----------------------------------------------------------
#  # Agglomerate data
#  altExps(mae[[1]]) <- splitByRanks(mae[[1]])
#  
#  library(miaViz)
#  
#  # Plot top taxa
#  top_taxa <- getTopFeatures(altExp(mae[[1]], "Phylum"), 10)
#  plotAbundance(altExp(mae[[1]], "Phylum")[top_taxa, ], rank = "Phylum")

## ----pcoa---------------------------------------------------------------------
#  # Apply relative transformation
#  mae[[1]] <- transformCounts(mae[[1]], method = "relabundance")
#  # Perform PCoA
#  mae[[1]] <- runMDS(
#      mae[[1]], assay.type = "relabundance",
#      FUN = vegan::vegdist, method = "bray")
#  # Plot
#  plotReducedDim(mae[[1]], "MDS", colour_by = "sample_environment.feature")

## ----get_download_urls--------------------------------------------------------
#  # Find list of available downloads, and filter for
#  dl_urls <- searchFile(mg, analyses_accessions, type = "analyses")

## ----show_tgt_urls------------------------------------------------------------
#  target_urls <- dl_urls[
#      dl_urls$attributes.description.label == "Predicted CDS with annotation", ]
#  head(target_urls)

## ----filter_dl_urls, message=FALSE--------------------------------------------
#  # Just select a single file from the target_urls list for demonstration.
#  cached_location <- getFile(mg, target_urls$download_url[[1]])
#  
#  # Where are the files?
#  c(cached_location)

## ----session_info-------------------------------------------------------------
#  sessionInfo()

